@@ -1101,7 +1101,7 @@ lnt_rename_docx <- function(tbl, encoding, simulate, verbose) {
 #' @author Johannes B. Gruber
 #' @export
 #' @importFrom stringdist stringdist
-#' @importFrom quanteda dfm docnames
+#' @importFrom quanteda dfm docnames tokens tokens_remove
 #' @importFrom quanteda.textstats textstat_simil
 #' @importFrom utils combn
 #' @examples
@@ -1177,12 +1177,8 @@ lnt_similarity <- function(texts,
       " articles over ", length(dates.d), " dates..."
     )
   }
-  text_dfm <- quanteda::dfm(texts,
-    tolower = TRUE,
-    remove = "[^[:alnum:]]",
-    valuetype = "regex",
-    verbose = FALSE
-  )
+  text_toks <- tokens_remove(tokens(texts), "[^[:alnum:]]", valuetype = "regex")
+  text_dfm <- dfm(text_toks, tolower = TRUE, verbose = FALSE)
   if (verbose) {
     message("\t...quanteda dfm constructed for similarity comparison [",
       format(
@@ -1609,13 +1605,15 @@ lnt_lookup.character <- function(x,
 #' @param ... Currently not used.
 #'
 #' @examples
+#' \dontrun{
 #' # Test similarity of articles
 #' duplicates.df <- lnt_similarity(
 #'   LNToutput = lnt_read(lnt_sample(copy = FALSE)),
 #'   threshold = 0.97
 #' )
-#'
+#' 
 #' lnt_diff(duplicates.df, min = 0.18, max = 0.30)
+#' }
 #' @author Johannes Gruber
 #' @export
 #' @importFrom quanteda tokens
@@ -1849,7 +1847,7 @@ lnt2rDNA <- function(x, what = "articles", collapse = TRUE) {
 
 #' @rdname lnt_convert
 #' @export
-#' @importFrom quanteda corpus metacorpus
+#' @importFrom quanteda corpus meta
 lnt2quanteda <- function(x, what = "articles", collapse = NULL, ...) {
   what <- tolower(what)
   if (!what %in% c("articles", "paragraphs")) {
@@ -1887,12 +1885,12 @@ lnt2quanteda <- function(x, what = "articles", collapse = NULL, ...) {
     )
   }
   dots <- list(...)
-  if (any(grepl("metacorpus", names(dots)))) {
+  if (any(grepl("meta", names(dots)))) {
     metacorpus <- c(list(
       converted_from = "LexiNexisTools"),
-      dots$metacorpus
+      dots$meta
     )
-    dots$metacorpus <- NULL
+    dots$meta <- NULL
   } else {
     metacorpus <- list(converted_from = "LexiNexisTools")
   }
@@ -1902,7 +1900,7 @@ lnt2quanteda <- function(x, what = "articles", collapse = NULL, ...) {
     docvars = meta,
     dots
   )
-  quanteda::metacorpus(dta, names(metacorpus)) <- unname(unlist(unname(metacorpus)))
+  quanteda::meta(dta, names(metacorpus)) <- unname(unlist(unname(metacorpus)))
   return(dta)
 }
 
@@ -2443,6 +2441,8 @@ lnt_read_lines <- function(files,
   if (length(files$.doc) > 0) {
     check_install("striprtf")
     if (length(files$.doc) > 1) {
+      # ignore lock files
+      files$.doc <- files$.doc[!grepl("^~\\$", basename(files$.doc))]
       lines_doc <- unlist(lapply(files$.doc, function(f) {
         out <- striprtf::read_rtf(f)
         names(out) <- rep(f, times = length(out))
@@ -2503,6 +2503,8 @@ lnt_read_lines <- function(files,
   if (length(files$docx) > 0) {
     check_install("xml2")
     if (length(files$docx) > 1) {
+      # ignore lock files
+      files$docx <- files$docx[!grepl("^~\\$", basename(files$docx))]
       lines_docx <- unlist(lapply(files$docx, function(f) {
         con <- unz(description = f, filename = "word/document.xml")
         out <- xml2::read_xml(con, encoding = "utf-8")
